@@ -5,7 +5,7 @@ import redis
 from copy import deepcopy
 from typing import Callable
 from django.db.models import Model as DjangoModel
-from django.db import models as django_fields
+from django.db.models.fields import models as django_fields
 from .utils import check_types, check_classes, get_ids_from_untyped_data
 from .cache import default_cache_func
 
